@@ -1,4 +1,6 @@
 import os
+from copy import deepcopy
+import boto3
 from typing import Dict, Any, List, Optional
 import pathlib
 from prefect import flow, task
@@ -9,7 +11,9 @@ import json
 from pcluster.api.controllers.image_operations_controller import describe_image
 from pcluster.api.models import DescribeImageResponseContent
 
+from mypy_boto3_logs.client import CloudWatchLogsClient
 from aws_pcluster_bootstrap_helpers.utils.logging import setup_logger
+from aws_pcluster_bootstrap_helpers.utils.cloudwatch import print_logs
 
 from pcluster import utils
 
@@ -25,9 +29,8 @@ DELETE_FAILED = "DELETE_FAILED"
 DELETE_COMPLETE = "DELETE_COMPLETE"
 
 
-def parse_image_status(data: Any):
-    # image_status = data.image_build_status
-    image_status = data["imageBuildStatus"]
+def parse_image_status(data: DescribeImageResponseContent):
+    image_status = data.image_build_status
     logger.info(f"Pcluster build status: {image_status}")
     if image_status == "BUILD_FAILED":
         raise Exception(f"Image build failed: {image_status}")
@@ -47,32 +50,76 @@ def parse_image_status(data: Any):
         raise Exception(f"Image status not compatible with bootstrap: {image_status}")
 
 
+def build_ami_logs(
+    data: DescribeImageResponseContent,
+    log_client: CloudWatchLogsClient,
+    start_time: int = 0
+):
+    """
+
+    'imageBuildLogsArn': 'arn:aws:logs:us-east-1:018835827632:log-group:/aws/imagebuilder/ParallelClusterImage-pcluster-3-2-1-wnl8bh-20221019'
+    Parameters
+    ----------
+    data
+    log_client
+    start_time
+
+    Returns
+    -------
+
+    """
+    log_stream_name = data.image_build_logs_arn
+    if not log_stream_name:
+        return 0
+    log_stream_name = log_stream_name.split(':').pop()
+    log_group = deepcopy(log_stream_name)
+    log_group = log_group.split('/')
+    log_group.pop()
+    log_group = list(filter(lambda x: x, log_group))
+    log_group = '/'.join(log_group)
+    log_stream_name = log_stream_name.split('/').pop()
+    start_time = print_logs(
+        client=log_client,
+        log_stream_name=log_stream_name,
+        log_group=log_group,
+        start_time=start_time
+    )
+    return start_time
+
+
 def build_in_progress(image_id: str, region="us-east-1"):
+    os.environ['AWS_DEFAULT_REGION'] = region
+    client = boto3.client('logs')
+    start_time = 0
+
     build_in_process = True
     n = 1
     while build_in_process:
-        with tempfile.NamedTemporaryFile(suffix=".json") as tmpfile:
-            logger.info(
-                f"Pcluster: {image_id}, Region: {region}, N: {1} Data file: {tmpfile.name}"
-            )
-            contents = shell_run_command(
-                command=f"pcluster describe-image --image-id {image_id} --region {region} > {tmpfile.name}",
-                return_all=True,
-            )
-            # build_data = describe_image(image_id=image_id)
-            build_data = json.loads(open(tmpfile.name, 'r').read())
-            logger.info(build_data)
+        logger.info(
+            f"Pcluster: {image_id}, Region: {region}, N: {n}"
+        )
+        build_data = describe_image(image_id=image_id, region=region)
+        logger.info(build_data)
+        try:
+            start_time = build_ami_logs(data=build_data, log_client=client, start_time=start_time)
+        except Exception as e:
+            # logs only exist for a certain time
+            # if they go away just skip this
+            pass
         build_in_process = parse_image_status(build_data)
+        print(f'Image Build:[{image_id} - {region}] Build in process: {build_in_process}')
+
         n = n + 1
         # sleep for 10 minutes
         if build_in_process:
             time.sleep(600)
+    return
 
 
 def build_complete(
     image_id: str, output_file: str, region="us-east-1"
 ) -> DescribeImageResponseContent:
-    build_data = describe_image(image_id=image_id)
+    build_data = describe_image(image_id=image_id, region=region)
     return build_data
 
 
